pub enum MessageError {
Show 21 variants
NoProfile,
NoEvent,
NoEventHandler,
UnknownCiEvent(CiEvent),
CiEventNotSet,
NoCommits,
UnknownRequest,
SerializeRequest(Box<dyn Error + Send + 'static>),
SerializeResponse(Box<dyn Error + Send + 'static>),
WriteRequest(Error),
WriteResponse(Error),
ReadLine(Error),
DeserializeRequest(Box<dyn Error + Send + 'static>),
DeserializeResponse(Box<dyn Error + Send + 'static>),
Trigger,
PatchCob(PatchId),
LatestPatchRevision(PatchId),
RepositoryError(Box<dyn Error + Send + 'static>),
CobStoreError(Box<dyn Error + Send + 'static>),
RadicleSurfError(Box<dyn Error + Send + 'static>),
UnknownPatchAction(String),
}Expand description
All possible errors from the CI broker messages.
Variants
NoProfile
RequestBuilder does not have profile set.
NoEvent
RequestBuilder does not have event set.
NoEventHandler
RequestBuilder does not have event handler set.
UnknownCiEvent(CiEvent)
We got a CI event we don’t know what to do with.
CiEventNotSet
CI event was not set for RequestBuilder.
NoCommits
Request message lacks commits to run CI on.
UnknownRequest
Request message is neither a “push” nor a “patch”
SerializeRequest(Box<dyn Error + Send + 'static>)
Failed to serialize a request message as JSON. This should never happen and likely indicates a programming failure.
SerializeResponse(Box<dyn Error + Send + 'static>)
Failed to serialize a response message as JSON. This should never happen and likely indicates a programming failure.
WriteRequest(Error)
Failed to write the serialized request message to an open file.
WriteResponse(Error)
Failed to write the serialized response message to an open file.
ReadLine(Error)
Failed to read a line of JSON from an open file.
DeserializeRequest(Box<dyn Error + Send + 'static>)
Failed to parse JSON as a request or a response.
DeserializeResponse(Box<dyn Error + Send + 'static>)
Failed to parse JSON as a response or a response.
Trigger
Error retrieving context to generate trigger.
PatchCob(PatchId)
Error looking up the patch COB.
LatestPatchRevision(PatchId)
Error looking up latest revision for a patch COB.
RepositoryError(Box<dyn Error + Send + 'static>)
Error from Radicle repository.
CobStoreError(Box<dyn Error + Send + 'static>)
Error from Radicle COB.
RadicleSurfError(Box<dyn Error + Send + 'static>)
Error from radicle-surf crate.
UnknownPatchAction(String)
Trying to create a PatchAction from an invalid value.